#[non_exhaustive]pub struct FsxProtocolSmb {
pub domain: Option<String>,
pub mount_options: Option<SmbMountOptions>,
pub password: String,
pub user: String,
pub managed_secret_config: Option<ManagedSecretConfig>,
pub cmk_secret_config: Option<CmkSecretConfig>,
pub custom_secret_config: Option<CustomSecretConfig>,
}Expand description
Specifies the Server Message Block (SMB) protocol configuration that DataSync uses to access your Amazon FSx for NetApp ONTAP file system's storage virtual machine (SVM). For more information, see Providing DataSync access to FSx for ONTAP file systems.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.domain: Option<String>Specifies the name of the Windows domain that your storage virtual machine (SVM) belongs to.
If you have multiple domains in your environment, configuring this setting makes sure that DataSync connects to the right SVM.
If you have multiple Active Directory domains in your environment, configuring this parameter makes sure that DataSync connects to the right SVM.
mount_options: Option<SmbMountOptions>Specifies the version of the Server Message Block (SMB) protocol that DataSync uses to access an SMB file server.
password: StringSpecifies the password of a user who has permission to access your SVM.
user: StringSpecifies a user that can mount and access the files, folders, and metadata in your SVM.
For information about choosing a user with the right level of access for your transfer, see Using the SMB protocol.
managed_secret_config: Option<ManagedSecretConfig>Describes configuration information for a DataSync-managed secret, such as a Password that DataSync uses to access a specific storage location. DataSync uses the default Amazon Web Services-managed KMS key to encrypt this secret in Secrets Manager.
Do not provide this for a CreateLocation request. ManagedSecretConfig is a ReadOnly property and is only be populated in the DescribeLocation response.
cmk_secret_config: Option<CmkSecretConfig>Specifies configuration information for a DataSync-managed secret, which includes the password that DataSync uses to access a specific FSx for ONTAP storage location (using SMB), with a customer-managed KMS key.
When you include this parameter as part of a CreateLocationFsxOntap request, you provide only the KMS key ARN. DataSync uses this KMS key together with the Password you specify for to create a DataSync-managed secret to store the location access credentials.
Make sure that DataSync has permission to access the KMS key that you specify. For more information, see Using a service-managed secret encrypted with a custom KMS key.
You can use either CmkSecretConfig (with Password) or CustomSecretConfig (without Password) to provide credentials for a CreateLocationFsxOntap request. Do not provide both parameters for the same request.
custom_secret_config: Option<CustomSecretConfig>Specifies configuration information for a customer-managed Secrets Manager secret where the password for an FSx for ONTAP storage location (using SMB) is stored in plain text, in Secrets Manager. This configuration includes the secret ARN, and the ARN for an IAM role that provides access to the secret. For more information, see Using a secret that you manage.
You can use either CmkSecretConfig (with Password) or CustomSecretConfig (without Password) to provide credentials for a CreateLocationFsxOntap request. Do not provide both parameters for the same request.
Implementations
Sourceimpl FsxProtocolSmb
impl FsxProtocolSmb
Sourcepub fn domain(&self) -> Option<&str>
pub fn domain(&self) -> Option<&str>
Specifies the name of the Windows domain that your storage virtual machine (SVM) belongs to.
If you have multiple domains in your environment, configuring this setting makes sure that DataSync connects to the right SVM.
If you have multiple Active Directory domains in your environment, configuring this parameter makes sure that DataSync connects to the right SVM.
Sourcepub fn mount_options(&self) -> Option<&SmbMountOptions>
pub fn mount_options(&self) -> Option<&SmbMountOptions>
Specifies the version of the Server Message Block (SMB) protocol that DataSync uses to access an SMB file server.
Sourcepub fn password(&self) -> &str
pub fn password(&self) -> &str
Specifies the password of a user who has permission to access your SVM.
Sourcepub fn user(&self) -> &str
pub fn user(&self) -> &str
Specifies a user that can mount and access the files, folders, and metadata in your SVM.
For information about choosing a user with the right level of access for your transfer, see Using the SMB protocol.
Sourcepub fn managed_secret_config(&self) -> Option<&ManagedSecretConfig>
pub fn managed_secret_config(&self) -> Option<&ManagedSecretConfig>
Describes configuration information for a DataSync-managed secret, such as a Password that DataSync uses to access a specific storage location. DataSync uses the default Amazon Web Services-managed KMS key to encrypt this secret in Secrets Manager.
Do not provide this for a CreateLocation request. ManagedSecretConfig is a ReadOnly property and is only be populated in the DescribeLocation response.
Sourcepub fn cmk_secret_config(&self) -> Option<&CmkSecretConfig>
pub fn cmk_secret_config(&self) -> Option<&CmkSecretConfig>
Specifies configuration information for a DataSync-managed secret, which includes the password that DataSync uses to access a specific FSx for ONTAP storage location (using SMB), with a customer-managed KMS key.
When you include this parameter as part of a CreateLocationFsxOntap request, you provide only the KMS key ARN. DataSync uses this KMS key together with the Password you specify for to create a DataSync-managed secret to store the location access credentials.
Make sure that DataSync has permission to access the KMS key that you specify. For more information, see Using a service-managed secret encrypted with a custom KMS key.
You can use either CmkSecretConfig (with Password) or CustomSecretConfig (without Password) to provide credentials for a CreateLocationFsxOntap request. Do not provide both parameters for the same request.
Sourcepub fn custom_secret_config(&self) -> Option<&CustomSecretConfig>
pub fn custom_secret_config(&self) -> Option<&CustomSecretConfig>
Specifies configuration information for a customer-managed Secrets Manager secret where the password for an FSx for ONTAP storage location (using SMB) is stored in plain text, in Secrets Manager. This configuration includes the secret ARN, and the ARN for an IAM role that provides access to the secret. For more information, see Using a secret that you manage.
You can use either CmkSecretConfig (with Password) or CustomSecretConfig (without Password) to provide credentials for a CreateLocationFsxOntap request. Do not provide both parameters for the same request.
Sourceimpl FsxProtocolSmb
impl FsxProtocolSmb
Sourcepub fn builder() -> FsxProtocolSmbBuilder
pub fn builder() -> FsxProtocolSmbBuilder
Creates a new builder-style object to manufacture FsxProtocolSmb.